@@ -27,10 +27,14 @@ from expiringdict import ExpiringDict
 
 
 logger = logging.getLogger(__name__)
-
+logger.addHandler(logging.NullHandler())
 mailparser_logger = logging.getLogger("mailparser")
 mailparser_logger.setLevel(logging.CRITICAL)
 
+url_regex = re.compile(r"([A-Za-z]+://)([-\w]+(?:\.\w[-\w]*)+)(:\d+)?(/[^.!,?"
+                       r"\"<>\[\]{}\s\x7F-\xFF]*(?:[.!,?]+[^.!,?"
+                       r"\"<>\[\]{}\s\x7F-\xFF]+)*)?")
+
 null_file = open(os.devnull, "w")
 
 markdown_maker = html2text.HTML2Text()
@@ -374,7 +378,10 @@ def parse_email(data: Union[str, bytes],
         parsed_email["body"] = "\n\n".join(parsed_email["text_html"])
         parsed_email["body_markdown"] = markdown_maker.handle(parsed_email[
                                                                   "body"])
-
+        body_urls = url_regex.findall(parsed_email["body_markdown"])
+        for i in range(len(body_urls)):
+            body_urls[i] = "".join(body_urls[i]).rstrip(")")
+        parsed_email["body_urls"] = body_urls
     if "received" in parsed_email:
         for received in parsed_email["received"]:
             if "date_utc" in received:
@@ -460,7 +467,6 @@ def parse_email(data: Union[str, bytes],
     if "body" not in parsed_email:
         parsed_email["body"] = None
         parsed_email["body_markdown"] = None
-
     auto_reply = all([_test_header_value("x-auto-response-suppress", "All"),
                       _test_header_value("auto-submitted", "auto_generated")])
     parsed_email["automatic_reply"] = auto_reply
@@ -531,7 +537,8 @@ def from_trusted_domain(message: Union[str, IOBase, Dict],
 
     header_name = "authentication-results"
     if use_authentication_results_original:
-        header_name = "authentication-results-original"
+        if "authentication-results-original" in parsed_email:
+            header_name = "authentication-results-original"
 
     if header_name not in parsed_email:
         return False
@@ -550,18 +557,17 @@ def from_trusted_domain(message: Union[str, IOBase, Dict],
                 if dkim_result == "pass" and sld in trusted_domains:
                     return True
         if "dmarc" in results:
-            if "dmarc" in results:
-                dmarc = results["dmarc"]
-                dmarc_result = dmarc["result"]
-                if "header.from" not in dmarc:
-                    return False
-                domain = dmarc["header.from"].lower().strip()
-                sld = publicsuffix2.get_sld(domain)
-                if dmarc_result == "pass" and domain in trusted_domains:
+            dmarc = results["dmarc"]
+            dmarc_result = dmarc["result"]
+            if "header.from" not in dmarc:
+                return False
+            domain = dmarc["header.from"].lower().strip()
+            sld = publicsuffix2.get_sld(domain)
+            if dmarc_result == "pass" and domain in trusted_domains:
+                return True
+            if include_sld:
+                if dmarc_result == "pass" and sld in trusted_domains:
                     return True
-                if include_sld:
-                    if dmarc_result == "pass" and sld in trusted_domains:
-                        return True
         return False
     if isinstance(results, list) and allow_multiple_authentication_results:
         dmarc = None
